/*
 * Bolo - A stable and beautiful blogging system based in Solo.
 * Copyright (c) 2020, https://github.com/adlered
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
/**
 * others for admin.
 *
 * @author <a href="http://vanessa.b3log.org">Liyuan Li</a>
 * @author <a href="http://88250.b3log.org">Liang Ding</a>
 * @version 1.4.0.0, Mar 20, 2019
 */

/* others 相关操作 */
var last = -1;
admin.others = {
  /*
   * @description 初始化
   */
  init: function () {
    $("#tabOthers").tabs();
    $('#loadMsg').text('')

    clearInterval(admin.others.intervalId)
    admin.others.intervalId = setInterval(() => {
      admin.others.getLog(false)
    }, 1000)
    admin.others.getLog(true)
  },

  getLog: (first) => {
    if (first) {
      $.ajax({
        url: Label.servePath + '/admin/logs',
        cache: false,
        timeout: 3000,
        success: function (result) {
          var json = result.result;
          for (var i = 0; i < json.length; i++) {
            var r = json[i];
            var rId = r.id;
            var rDate = r.date;
            var rLevel = r.level;
            var rSrc = r.name + ':' + r.lineNumber;
            var msg = r.message;
            var res = '[ ' + rLevel + ' ] [ ' + rDate + ' ' + rSrc + ' ] ' + msg + '\n';
            $('#memFree').html((r.freeMemory / (1024 * 1024)).toFixed(2) + ' MB');
            if (r.throwable !== undefined) {
              res += r.throwable.class + ': ' + r.throwable.message + '\n';
              for (var j = 0; j < r.throwable.stackTrace.length; j++) {
                res += r.throwable.stackTrace[j] + '\n';
              }
            }
            $('#tabOthersPanel_log textarea').append(res);
            last = rId;
          }
        },
      })
    } else {
      $.ajax({
        url: Label.servePath + '/admin/logs',
        cache: false,
        timeout: 3000,
        success: function (result) {
          var json = result.result;
          var r = json[json.length - 1];
          var rId = r.id;
          if (rId !== last) {
            var rDate = r.date;
            var rLevel = r.level;
            var rSrc = r.name + ':' + r.lineNumber;
            var msg = r.message;
            var res = '[ ' + rLevel + ' ] [ ' + rDate + ' ' + rSrc + ' ] ' + msg  + '\n';
            $('#memFree').html((r.freeMemory / (1024 * 1024)).toFixed(2) + ' MB');
            if (r.throwable !== undefined) {
              res += r.throwable.class + ': ' + r.throwable.message + '\n';
              for (var j = 0; j < r.throwable.stackTrace.length; j++) {
                res += r.throwable.stackTrace[j] + '\n';
              }
            }
            $('#tabOthersPanel_log textarea').append(res);
          }
          last = rId;
        },
      })
    }
  },
  /*
   * @description 移除未使用的存档
   */
  removeUnusedArchives: function () {
    $("#tipMsg").text("");

    $.ajax({
      url: Label.servePath + "/console/archive/unused",
      type: "DELETE",
      cache: false,
      success: function (result, textStatus) {
        $("#tipMsg").text(result.msg);
      }
    });
  },
  /*
   * @description 移除未使用的标签
   */
  removeUnusedTags: function () {
    $("#tipMsg").text("");

    $.ajax({
      url: Label.servePath + "/console/tag/unused",
      type: "DELETE",
      cache: false,
      success: function (result, textStatus) {
        $("#tipMsg").text(result.msg);
      }
    });
  },
  /*
   * @description 导出数据为 SQL 文件
   */
  exportSQL: function () {
    $("#tipMsg").text("");

    $.ajax({
      url: Label.servePath + "/console/export/sql",
      type: "GET",
      cache: false,
      success: function (result, textStatus) {
        // AJAX 下载文件的话这里会发两次请求，用 sc 来判断是否是文件，如果没有 sc 说明文件可以下载（实际上就是 result）
        if (!result.sc) {
          // 再发一次请求进行正式下载
          window.location = Label.servePath + "/console/export/sql";
        } else {
          $("#tipMsg").text(result.msg);
        }
      }
    });
  },
  /*
 * @description 导出数据为 JSON 文件
 */
  exportJSON: function () {
    $("#tipMsg").text("");

    $.ajax({
      url: Label.servePath + "/console/export/json",
      type: "GET",
      cache: false,
      success: function (result, textStatus) {
        // AJAX 下载文件的话这里会发两次请求，用 sc 来判断是否是文件，如果没有 sc 说明文件可以下载（实际上就是 result）
        if (!result.sc) {
          // 再发一次请求进行正式下载
          window.location = Label.servePath + "/console/export/json";
        } else {
          $("#tipMsg").text(result.msg);
        }
      }
    });
  },
  /*
  * @description 导出数据为 Hexo Markdown 文件
  */
  exportHexo: function () {
    $("#tipMsg").text("");

    $.ajax({
      url: Label.servePath + "/console/export/hexo",
      type: "GET",
      cache: false,
      success: function (result, textStatus) {
        // AJAX 下载文件的话这里会发两次请求，用 sc 来判断是否是文件，如果没有 sc 说明文件可以下载（实际上就是 result）
        if (!result.sc) {
          // 再发一次请求进行正式下载
          window.location = Label.servePath + "/console/export/hexo";
        } else {
          $("#tipMsg").text(result.msg);
        }
      }
    });
  },
  /*
   * 获取未使用的标签。
   * XXX: Not used this function yet.
   */
  getUnusedTags: function () {
    $.ajax({
      url: Label.servePath + "/console/tag/unused",
      type: "GET",
      cache: false,
      success: function (result, textStatus) {
        $("#tipMsg").text(result.msg);
        if (!result.sc) {
          $("#loadMsg").text("");
          return;
        }

        var unusedTags = result.unusedTags;
        if (0 === unusedTags.length) {
          return;
        }
      }
    });
  }
};

/*
 * 注册到 admin 进行管理 
 */
admin.register.others = {
  "obj": admin.others,
  "init": admin.others.init,
  "refresh": function () {
    admin.clearTip();
  }
};
